scoretools.make_repeated_notes_from_time_signatures
===================================================

.. autofunction:: abjad.tools.scoretools.make_repeated_notes_from_time_signatures.make_repeated_notes_from_time_signatures
